<?php

use Kirby\Http\Cookie;

class Cookies
{
    public static function checkCookieAccepted(string $key) : bool
    {
        if(!Cookie::exists('cookies_accepted')) {
            return false;
        }

        $accepted = Cookie::get('cookies_accepted');
        if($accepted === 'none') {
            return false;
        } else if ($accepted === 'all') {
            return true;
        }

        $selection = Cookie::get('cookies_selected', '');
        $selection = explode(';', $selection);
        return in_array($key, $selection);
    }

    public static function setCookieAccepted(array $keys)
    {
        Cookie::set('cookies_accepted', 'selection');
        Cookie::set('cookies_selected', implode(';', $keys));
    }

    public static function setNoCookiesAccepted()
    {
        Cookie::set('cookies_accepted', 'none');
        Cookie::remove('cookies_selected');
    }

    public static function setAllCookiesAccepted()
    {
        Cookie::set('cookies_accepted', 'all');
    }

    public static function getAllAcceptedCookies()
    {
        $accepted = [];
        foreach(option('cookie-jar.cookies') as $cookie => $value) {
            if (Cookies::checkCookieAccepted($cookie)) {
                $accepted[] = $cookie;
            }
        }
        return $accepted;
    }

    public static function getCookieSnippets()
    {
        $result = '';
        foreach(Cookies::getAllAcceptedCookies() as $cookie) {
            $cookie = option('cookie-jar.cookies')[$cookie];
            if (isset($cookie['snippets'])) {
                foreach($cookie['snippets'] as $snippet) {
                    $result .= snippet($snippet, [], true);
                }
            }
        }
        return $result;
    }
}
